@@ -6,11 +6,11 @@ class FlaskDeployer(KnowledgeDeployer):
     _registry_keys = ['flask']
 
     def run(self, **kwargs):
-        app = self.app
-        return app.run(
-            debug=app.config['DEBUG'],
+        self.app.start_indexing()
+        return self.app.run(
+            debug=self.app.config['DEBUG'],
             host=self.host,
             port=self.port,
-            threaded=app.check_thread_support(),
+            threaded=self.app.check_thread_support(),
             **kwargs
         )
