@@ -3,17 +3,16 @@ import sys
 import datetime
 import logging
 import traceback
-from builtins import str
-from future.utils import raise_with_traceback
 from flask import current_app, request
 from flask_login import UserMixin
 from flask_sqlalchemy import SQLAlchemy
 from collections import defaultdict
 
-from sqlalchemy import func, distinct, and_, select, UniqueConstraint
+from sqlalchemy import func, distinct, and_, select, Index, UniqueConstraint
 
 from knowledge_repo._version import __version__
 from knowledge_repo.repository import KnowledgeRepository
+from knowledge_repo.utils.types import MediumText
 from .proxies import current_user, current_repo, db_session
 from .utils.models import unique_constructor
 from .utils.search import get_keywords
@@ -123,9 +122,9 @@ class ErrorLog(db.Model):
         filename = os.path.relpath(filename, os.path.join(os.path.dirname(__file__), '..'))
         return ErrorLog(
             function=function,
-            location=u'{}:{}'.format(filename, linenumber),
-            message=u'{}: {}'.format(e.__class__.__name__, u"; ".join(str(a) for a in e.args)),
-            traceback=u"\n".join(traceback.format_tb(tb))
+            location='{}:{}'.format(filename, linenumber),
+            message='{}: {}'.format(e.__class__.__name__, "; ".join(str(a) for a in e.args)),
+            traceback="\n".join(traceback.format_tb(tb))
         )
 
     @classmethod
@@ -137,7 +136,8 @@ class ErrorLog(db.Model):
                 db_session.rollback()
                 db_session.add(ErrorLog.from_exception(e))
                 db_session.commit()
-                raise_with_traceback(e)
+                tb = sys.exc_info()[2]
+                raise e.with_traceback(tb=sys.exc_info()[2])
         return wrapped
 
 
@@ -156,6 +156,8 @@ class PageView(db.Model):
     created_at = db.Column(db.DateTime, default=func.now())
     version = db.Column(db.String(100), default=__version__)
 
+    __table_args__ = (Index("object_id_type_action_index", object_id, object_type, object_action),)
+
     class logged(object):
 
         def __init__(self, route, object_extractor=None):
@@ -188,7 +190,8 @@ class PageView(db.Model):
                 errorlog = ErrorLog.from_exception(e)
                 db_session.add(errorlog)
                 db_session.commit()
-                raise_with_traceback(e)
+                tb = sys.exc_info()[2]
+                raise e.with_traceback(tb=sys.exc_info()[2])
             finally:
                 # Extract object id and type after response generated (if requested) to ensure
                 # most recent data is collected
@@ -337,7 +340,7 @@ class Tag(db.Model):
     def description(self):
         if self._description:
             return self._description
-        return u"All posts with tag '{}'.".format(self.name)
+        return "All posts with tag '{}'.".format(self.name)
 
     @description.expression
     def description(self):
@@ -404,7 +407,7 @@ class Post(db.Model):
 
     @hybrid_property
     def authors_string(self):
-        return u', '.join([author.format_name for author in self.authors])
+        return ', '.join([author.format_name for author in self.authors])
 
     @authors_string.expression
     def authors_string(self):
@@ -631,7 +634,7 @@ class Email(db.Model):
     object_type = db.Column(db.String(100))
     sent_at = db.Column(db.DateTime, default=func.now())
     subject = db.Column(db.Text)
-    text = db.Column(db.Text)
+    text = db.Column(MediumText())
 
 
 @unique_constructor(
