@@ -9,6 +9,9 @@ stats_view = Permission(roles.stats_view)
 # Index permissions
 index_view = Permission(roles.index_view)
 
+# Tags permissions
+tags_view = Permission(roles.tags_view)
+
 # Post permissions
 post_comment = Permission(roles.post_comment)
 post_edit = Permission(roles.post_edit)
