@@ -11,6 +11,9 @@ stats_view = RoleNeed('stats_view')
 # Index roles
 index_view = RoleNeed('index_view')
 
+# Tags roles
+tags_view = RoleNeed('tags_view')
+
 # Post roles
 post_comment = RoleNeed('post_comment')
 post_edit = RoleNeed('post_edit')
