@@ -1,6 +1,5 @@
 import logging
 import os
-from builtins import str
 from flask import request, url_for, redirect, render_template, current_app, Blueprint, g, Response, abort
 
 from .. import permissions
@@ -54,7 +53,7 @@ def render(path):
                               .filter(Post.path == knowledge_aliases[path])
                               .first())
     if not post:
-        logger.warning(u"unable to find post at {}".format(path))
+        logger.warning("unable to find post at {}".format(path))
         return abort(404)
     if post.contains_excluded_tag:
         # It's possible that someone gets a direct link to a post that has an excluded tag
@@ -113,7 +112,8 @@ def render(path):
                                is_private=(post.private == 1),
                                is_author=is_author,
                                can_download=permissions.post_download.can(),
-                               downloads=post.kp.src_paths)
+                               downloads=post.kp.src_paths,
+                               collapse_code=current_app.config['COLLAPSE_CODE_DEFAULT'])
     return rendered
 
 
@@ -146,7 +146,7 @@ def _render_preview(path, tmpl):
             post = current_repo.post(knowledge_aliases[path])
 
     if not post:
-        raise Exception(u"unable to find post at {}".format(path))
+        raise Exception("unable to find post at {}".format(path))
 
     rendered = render_post(post, with_toc=True)
     raw_post = render_post_raw(post) if (mode == 'raw') else None
@@ -159,7 +159,7 @@ def _render_preview(path, tmpl):
                            raw_post=raw_post,
                            comments=[],
                            username=None,
-                           post_author=u', '.join(post.headers['authors']),
+                           post_author=', '.join(post.headers['authors']),
                            title=post.headers['title'],
                            page_views=0,
                            unique_views=0,
@@ -196,7 +196,13 @@ def download():
         return Response(
             post.to_string(format=resource_type),
             mimetype="application/zip",
-            headers={u"Content-disposition": "attachment; filename={}".format(filename)})
+            headers={"Content-disposition": "attachment; filename={}".format(filename)})
+    elif resource_type == 'pdf':
+        filename = os.path.basename(post.path)[:-3] + '.pdf'
+        return Response(
+            post.to_string(format=resource_type),
+            mimetype="application/pdf",
+            headers={"Content-disposition": "attachment; filename={}".format(filename)})
     elif resource_type == 'source':
         path = request.args.get('path', None)
         assert path is not None, "Source path not provided."
@@ -204,6 +210,6 @@ def download():
         return Response(
             post._read_ref(path),
             mimetype="application/octet-stream",
-            headers={u"Content-disposition": "attachment; filename={}".format(os.path.basename(path))})
+            headers={"Content-disposition": "attachment; filename={}".format(os.path.basename(path))})
     else:
-        raise RuntimeError(u"Invalid resource_type: {}".format(resource_type))
+        raise RuntimeError("Invalid resource_type: {}".format(resource_type))
