@@ -1,16 +1,17 @@
 """
 This file deals with all of the email functions.
 """
-
+import base64
 import logging
+import re
 
+import requests
 from flask import render_template, current_app, url_for
 from flask_mail import Message
 
 from ..proxies import db_session
 from ..proxies import current_repo
-from ..models import Email, Subscription, User, Post
-from ..utils.render import render_post
+from ..models import Email, Subscription, User
 
 logger = logging.getLogger(__name__)
 
@@ -88,21 +89,53 @@ def send_subscription_email(post, tag):
         return
 
     default_recipients = ['knowledge_consumer@notreal.com']
-    subject = u"New knowledge post with tag [{}]!".format(tag.name)
-    msg = Message(subject=subject,
-                  recipients=default_recipients,
-                  bcc=recipients_bcc)
+    subject = "New knowledge post: {}".format(post.title)
+    post_authors = [p.format_name for p in post.authors]
+    post_tags = [t.name for t in post.tags]
+    msg = Message(subject=subject, recipients=default_recipients, bcc=recipients_bcc)
 
-    # Iterate over fetched image files and attach them to email
-    post_text = render_post(post)
+    # Extract bytes from post thumbnail or fallback to the default one
+    thumb_bytes = None
+    if post.thumbnail:
+        try:
+            reg_search = re.search('data:.*;base64,(.*)', post.thumbnail)
+            if reg_search:
+                thumb_bytes = base64.b64decode(reg_search.group(1))
+            else:
+                # Download image from url
+                response = requests.get(post.thumbnail)
+                if response.ok:
+                    thumb_bytes = response.content
+        except:
+            pass
 
+    if not thumb_bytes:
+        with current_app.open_resource('static/images/default_thumbnail.png') as f:
+            thumb_bytes = f.read()
+
+    # Attach thumbnail to the email (base64 embedded images are not supported by many email clients)
+    msg.attach('thumb.png', 'image/png', thumb_bytes, 'inline', headers=[['Content-ID', '<Thumb>']])
+
+    # Plain mail
     msg.body = render_template("email_templates/subscription_email.txt",
                                full_tag=tag.name,
                                page_id=post.path,
-                               post_text=post_text,
+                               post_title=post.title,
+                               post_tldr=post.tldr,
+                               post_authors=post_authors,
+                               post_tags=post_tags,
                                knowledge_app_base_url=current_app.config['SERVER_NAME'])
 
-    msg.html = post_text
+    # Rich email
+    msg.html = render_template("email_templates/subscription_email.html",
+                               full_tag=tag.name,
+                               page_id=post.path,
+                               post_title=post.title,
+                               post_tldr=post.tldr,
+                               post_authors=post_authors,
+                               post_tags=post_tags,
+                               post_thumbnail=thumb_bytes,
+                               knowledge_app_base_url=current_app.config['SERVER_NAME'])
 
     for user in recipient_users:
         # mark email as sent just before you send the email
@@ -112,7 +145,7 @@ def send_subscription_email(post, tag):
                            object_id=post.id,
                            object_type="post",
                            subject=subject,
-                           text=post_text)
+                           text=msg.html)
         db_session.add(email_sent)
         db_session.commit()
 
