@@ -1,8 +1,5 @@
 import datetime
 
-import six
-from past.builtins import basestring
-
 from ..post import HEADER_OPTIONAL_FIELD_TYPES, HEADER_REQUIRED_FIELD_TYPES
 from ..postprocessor import KnowledgePostProcessor
 
